@@ -1,15 +1,17 @@
 
-from lsptoolbox.database_class_define import DatabaseConnectBean,DatabaseClearThread,DatabaseManagerBean
+from src.lsptoolbox.database_class_define import DatabaseClearThread,DatabaseManagerBean
 
 
-print(r'''
-.__                             __                .__ ___.                 
-|  |   ____________           _/  |_  ____   ____ |  |\_ |__   _______  ___
-|  |  /  ___/\____ \   ______ \   __\/  _ \ /  _ \|  | | __ \ /  _ \  \/  /
-|  |__\___ \ |  |_> > /_____/  |  | (  <_> |  <_> )  |_| \_\ (  <_> >    < 
-|____/____  >|   __/           |__|  \____/ \____/|____/___  /\____/__/\_ \
-          \/ |__|                                          \/            \/
-''')
+# print(r'''
+# .__                             __                .__ ___.
+# |  |   ____________           _/  |_  ____   ____ |  |\_ |__   _______  ___
+# |  |  /  ___/\____ \   ______ \   __\/  _ \ /  _ \|  | | __ \ /  _ \  \/  /
+# |  |__\___ \ |  |_> > /_____/  |  | (  <_> |  <_> )  |_| \_\ (  <_> >    <
+# |____/____  >|   __/           |__|  \____/ \____/|____/___  /\____/__/\_ \
+#           \/ |__|                                          \/            \/
+# ''')
+
+print(r'''thanks for using LSP tool set ,my phone is 15608447849 . ''')
 
 _db_mng_map = {}
 
@@ -33,18 +35,25 @@ def setting_database(database_obj):
 def load_database_config(config):
 
     db_clear_thread = DatabaseClearThread()
-    # print('连接检测线程',db_clear_thread)
+    print('连接检测线程',db_clear_thread)
     for session in  config.sections():
         if session.startswith('dbload::'):
             mngName = session.replace('dbload::','',1)
 
-            databaseConnectBean = DatabaseManagerBean(config.get(session, 'dbtype'),
+            try:
+                charset = config.get(session, 'charset')
+            except:
+                charset = 'utf8'
+
+            databaseConnectBean = DatabaseManagerBean( db_clear_thread,
+                                                       config.get(session, 'dbtype'),
                                                        config.get(session, 'host'),
                                                        config.get(session, 'port'),
                                                        config.get(session, 'username'),
                                                        config.get(session, 'password'),
                                                        config.get(session, 'database'),
-                                                       db_clear_thread)
+                                                       charset
+                                                       )
             setting_database(databaseConnectBean)
             _db_mng_map[mngName] = databaseConnectBean
             print("加载数据库管理 %s,%s" % (mngName, str(_db_mng_map[mngName])))
